@@ -17,6 +17,7 @@ from typing import (
 from urllib.error import HTTPError
 
 import pandas as pd
+import requests
 
 from erddapy import ERDDAP
 from intake.catalog.base import Catalog
@@ -237,10 +238,18 @@ class ERDDAPCatalog(Catalog):
             except HTTPError as e:
                 if e.code == 404:
                     log.warning(f"search {url} returned HTTP 404")
-                    continue
-                raise
+                    df = pd.DataFrame({"datasetID": []})
+                else:
+                    raise
+            except requests.exceptions.HTTPError as e:
+                if e.response.status_code == 404:
+                    log.warning(f"search {url} returned HTTP 404")
+                    df = pd.DataFrame({"datasetID": []})
+                else:
+                    raise
             df.rename(columns={"Dataset ID": "datasetID"}, inplace=True)
             frames.append(df)
+
         if self._query_type == "union":
             result = pd.concat(frames)
             result = result.drop_duplicates("datasetID")
